/*
 * Proyecto:      Enviarpdf
 * Fichero:       MainPage.prg
 * Descripcin:   Aplicacin CGI de EnviarEmail
 * Autor:         Pedro Amaro
 *                Copyright 2019-2023  Nefele.dev
 * Fecha:         28/02/2021
 */

#include "Xailer.ch"
#include "Nefele.ch"

//------------------------------------------------------------------------------
//Funcin principal de la app Web
/*
   Este CGI realiza el envo de un email utilizando solo Harbour
   Es necesario aadir en el proyecto las librerias:
      de harbour: hbssl y hbtip
      de 3party\opensssl\lib: ssl y crypto
      de mingw: security
   Y poner en la misma carpeta del ejecutable las DLL libcrypto-1_1.dll y libssl-1_1.dll que encontrar en la
   carpera "Copiar contenido en cgi-bin"
*/

REQUEST __HBEXTERN__HBSSL__

/*
   cServer     -> Required. IP or domain name of the mail server
   nPort       -> Optional. Port used my email server
   cFrom       -> Required. Email address of the sender
   xTo         -> Required. Character string or array of email addresses to send the email to
   xCC         -> Optional. Character string or array of email addresses for CC (Carbon Copy)
   xBCC        -> Optional. Character string or array of email addresses for BCC (Blind Carbon Copy)
   cBody       -> Optional. The body message of the email as text, or the filename of the HTML message to send.
   cSubject    -> Optional. Subject of the sending email
   aFiles      -> Optional. Array of attachments to the email to send
   cUser       -> Required. User name for the POP3 server
   cPass       -> Required. Password for cUser
   cPopServer  -> Required. POP3 server name or address
   nPriority   -> Optional. Email priority: 1=High, 3=Normal (Standard), 5=Low
   lRead       -> Optional. If set to .T., a confirmation request is send. Standard setting is .F.
   xTrace      -> Optional. If set to .T., a log file is created (smtp-<n>.log). Standard setting is .F.
                            If a block is passed, it will be called for each log event with the message a string, no param on session close.
   lPopAuth    -> Optional. Do POP3 authentication before sending mail.
   lNoAuth     -> Optional. Disable authentication methods
   nTimeOut    -> Optional. Number os ms to wait default 10000 (10s)
   cReplyTo    -> Optional.
   lSSL        -> Optional. Need SSL at connect time (TLS need this param set to False)
   cSMTPPass   -> Optional.
   cCharset    -> Optional.
   cEncoding   -> Optional.
   cClientHost -> Optional. Domain name of the SMTP client in the format smtp.example.net OR
                            client IP surrounded by brackets as [127.0.0.1] for IPv4 or as [ipv6:address] (f.e. '[ipv6:::1]') for IPv6
                            Note: This parameter is optional for backwards compatibility, but should be provided to comply with RFC 2812.
 */

//------------------------------------------------------------------------------

PROCEDURE AjaxSendMail()
   LOCAL cTo         := oCGI:GetCgiValue( "para" )
   LOCAL cHost       := oCGI:GetCgiValue( "host", "" )
   LOCAL nPort       := Val( oCGI:GetCgiValue( "port", "465" ) )
   LOCAL cFrom       := oCGI:GetCgiValue( "from", "" )
   LOCAL cPassword   := oCGI:GetCgiValue( "pass", "" )
   LOCAL cUser       := oCGI:GetCgiValue( "user", "" )
   LOCAL cCC         := oCGI:GetCgiValue( "cc" )
   LOCAL aBCC        := {}
   LOCAL cBody       := oCGI:GetCgiValue( "body", "Este es un email enviado desde Nefele_Samples" )
   LOCAL cSubject    := oCGI:GetCgiValue( "subject", "Prueba de Email" )
   LOCAL aAttachment := Nil
   LOCAL nPriority   := Nil
   LOCAL lRead       := Nil
   LOCAL lTrace      := .F.
   LOCAL lNoAuth     := Nil
   LOCAL nTimeOut    := Nil
   LOCAL cReplyTo    := oCGI:GetCgiValue( "replyto" )
   LOCAL lOk         := .F.
   LOCAL cIniFile    := oCGI:GetCgiValue( "inifile", "smtpconfig.ini" )

   nfl_Console("Inicio de enviaremail a " + cTo )

   cCC      := IIF( Empty( cCC ), Nil, cCC )
   cReplyTo := IIF( Empty( cReplyTo ), Nil, cReplyTo )

   IF File( ".\" + cIniFile )
      WITH OBJECT TIni():New( ".\" + cIniFile )
         cHost     := :GetEntry("SMTP","HOST","")
         nPort     := :GetNumeric("SMTP","PORT",0)
         cFrom     := :GetEntry("SMTP","FROM")
         cPassword := :GetEntry("SMTP","PASS")
         cUser     := :GetEntry("SMTP","USER", cFrom)
      END WITH
   ENDIF

   IF Empty( cHost ) .OR. Empty( cFrom ) .OR. Empty( cPassword )
      With Object WMsgAlert():New()
         :lTagScript       := .F.
         :cText            := "No esta configurado el servidor SMTP."
         :cTitle           := "Email NO Enviado"
         :cType            := "error"
         :nPrimaryDelay    := 5
         :cConfirmButton   := "Aceptar"

         :Create()

         oCGI:SendScript( :FullHtml() )
      End With
      QUIT
   ENDIF

   IF !Empty(cTo)
      IF ! tip_SSL()
         nfl_Console( "Error: Requires SSL support" )
      ELSE

         lOk := tip_MailSend( ;
            cHost, ;
            nPort, ;
            cFrom, ;
            cTo, ;
            cCC, ;
            aBCC, ;
            cBody, ;
            cSubject, ;
            aAttachment, ;
            cUser, ;
            cPassword, ;
            "", ; // Servidor POP
            nPriority, ;
            lRead, ;
            lTrace, ;
            .F., ; // lPopAuth
            lNoAuth, ;
            nTimeOut, ;
            cReplyTo, ;
            nPort == 465 ) // lSSL
      ENDIF
   ENDIF

   if lOk
      With Object WMsgAlert():New()
         :lTagScript       := .F.
         :cText            := "Compruebe su cuenta de correo."
         :cTitle           := "Email Enviado"
         :cType            := "info"
         :nPrimaryDelay    := 5
         :cConfirmButton   := "Aceptar"

         :Create()

         oCGI:SendScript( :FullHtml() )
      End With
   ELSE
      With Object WMsgAlert():New()
         :lTagScript       := .F.
         :cText            := "Se ha producido un error al enviar el email."
         :cTitle           := "Email NO Enviado"
         :cType            := "error"
         :nPrimaryDelay    := 5
         :cConfirmButton   := "Aceptar"

         :Create()
         oCGI:SendScript( :FullHtml() )
      End With
   ENDIF

RETURN

//------------------------------------------------------------------------------